@@ -3,7 +3,8 @@ import pandas as pd
 from .classifiers import classifier_dict
 
 
-def local_test(x_train, pit_train, x_test, alphas=np.linspace(0.0, 1.0, 11), clf_name='MLP', n_trials=1000):
+def local_test(x_train, pit_train, x_test, alphas=np.linspace(0.0, 1.0, 11), clf_name='MLP', n_trials=1000,
+               return_T=False):
     
     clf = classifier_dict[clf_name]
     
@@ -35,5 +36,7 @@ def local_test(x_train, pit_train, x_test, alphas=np.linspace(0.0, 1.0, 11), clf
     ### compute local p-value
     local_pvalue = sum(1* (Ti_value < pd.Series(all_unif_Ti_values))) / len(all_unif_Ti_values)
     
-    return local_pvalue
-
+    if return_T:
+        return local_pvalue, Ti_value
+    else:
+        return local_pvalue
